yakumo.nova.v2.server

Package yakumo :: Package nova :: Package v2 :: Module server |
[hide private]
[frames] | no frames]

# Module server

source code

Resource class and its manager for servers in Compute API v2

Classes | [hide private]
| Resource Resource class for servers in Compute API v2
| Manager Manager class for servers in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('access_ip
      v4', 'accessIPv4', mapper.Noop), ('access_ipv6', 'accessIPv6', mapper.
      Noop), ('addresses', 'addresses', mapper.Noop), ('host', 'OS-EXT-SRV-A
      TTR:host', mapper.Noop), ('networks', 'networks', mapper.Noop), ('disk
      s', 'block_device_mapping_v2', mapper.Noop), ('user_data', 'user_data'
      , mapper.Base64), ('progress', 'progress', mapper.Noop), ('status', 's
      tatus', mapper.Noop), ('task_state', 'OS-EXT-STS:task_state', mapper.N
      oop), ('created_at', 'created', mapper.DateTime), ('updated_at', 'upda
      ...